TokType

Enum TokType 

pub enum TokType {
    String(String),
    Int(usize),
    Colon,
    Equals,
    Minus,
    Comma,
    LParen,
    RParen,
    At,
}
Token Representing content from the txt file format of the binary database

Variants



String(String)

String Token



Int(usize)

Integer represented as usize



Colon



Equals



Minus



Comma



LParen



RParen



At

Single @ Token

Implementations

Source

impl TokType

pub fn parse<P: AsRef<Path>>(file: P) -> Result<Vec<Self>>

Parse a file from filesystem to a Vec of Tokens

Arguments
  • path - path to db.txt on disk
Examples found in repository?
examples/generate-regdb.rs (line 13)
4fn main() {
5    if args().len() != 3 {
6        eprintln!("Usage: {} input-file output-file", args().nth(0).unwrap());
7        std::process::exit(-1);
8    }
9
10    let in_file = args().nth(1).unwrap();
11    let out_file = args().nth(2).unwrap();
12
13    let lexer = TokType::parse(in_file).unwrap();
14
15    let db = RegDB::from_lexer(lexer).unwrap();
16
17    let bin_db = Binary::from_regdb(&db).unwrap();
18
19    bin_db.write_file(out_file).unwrap();
20}
pub fn parse_str(db: &str) -> Result<Vec<Self>>

Parse a string to a Vec of Tokens

Arguments
  • db - string of the database
Example
use wireless_regdb::TokType;
let tokens = TokType::parse_str("wmmrule: ETSI").unwrap();
pub fn get_string(&self) -> Result<String>

Return the string of the token, if the token contains a string

Example
use wireless_regdb::TokType;
let token = TokType::String("hello_world".to_string());
let content = token.get_string().unwrap();
pub fn get_int(&self) -> Result<usize>

Return the usize of the token, if the token contains an integer

Example
use wireless_regdb::TokType;
let token = TokType::Int(1337);
let content = token.get_int().unwrap();